| Title: | Threshold Cut Point of Probability for a Binary Classifier Model |
|---|---|
| Description: | Allows to view the optimal probability cut-off point at which the Sensitivity and Specificity meets and its a best way to minimize both Type-1 and Type-2 error for a binary Classifier in determining the Probability threshold. |
| Authors: | Navinkumar Nedunchezhian |
| Maintainer: | Navinkumar Nedunchezhian <[email protected]> |
| License: | GPL-2 |
| Version: | 0.2 |
| Built: | 2026-05-14 06:19:04 UTC |
| Source: | https://github.com/cran/BinarybalancedCut |
Prints 'Chart of sensitivity & specificity'.
Binary_threshold(probability,class)Binary_threshold(probability,class)
probability |
Probability Obtained from the model |
class |
Actual Class of the datasets |
set.seed(100);disease <- sample(c("yes","no"), 1000, replace=TRUE); Probabilities<-sample(seq(0,1,by=0.01),1000,replace=TRUE); Binary_threshold(Probabilities,disease)set.seed(100);disease <- sample(c("yes","no"), 1000, replace=TRUE); Probabilities<-sample(seq(0,1,by=0.01),1000,replace=TRUE); Binary_threshold(Probabilities,disease)