Welcome to ClientVPS Mirrors

Help for package BinarybalancedCut
Type: Package
Version: 0.2
Title: Threshold Cut Point of Probability for a Binary Classifier Model
Date: 2017-09-02
Author: Navinkumar Nedunchezhian
Maintainer: Navinkumar Nedunchezhian <navinkumar.nedunchezhian@gmail.com>
Description: Allows to view the optimal probability cut-off point at which the Sensitivity and Specificity meets and its a best way to minimize both Type-1 and Type-2 error for a binary Classifier in determining the Probability threshold.
License: GPL-2
LazyData: FALSE
Imports: ggplot2,reshape2
Suggests: knitr
NeedsCompilation: no
Packaged: 2017-09-02 16:27:17 UTC; NSD
Repository: CRAN
Date/Publication: 2017-09-02 17:27:38 UTC

This Supports the datascientist to determine the optimal threshold for binary classifier problem by visuallizing the sensitivity, specificity and accurarcy of the given model

Description

Prints 'Chart of sensitivity & specificity'.

Usage

Binary_threshold(probability,class)

Arguments

probability

Probability Obtained from the model

class

Actual Class of the datasets

Examples

set.seed(100);disease <- sample(c("yes","no"), 1000, replace=TRUE);
Probabilities<-sample(seq(0,1,by=0.01),1000,replace=TRUE);
Binary_threshold(Probabilities,disease)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.